Channel class

Constructors

Channel({String? channelId, String? title, String? thumbnail, String? videoCount})
Channel.fromMap(Map<String, dynamic>? map)
factory

Properties

channelId ↔ String?
Youtube channel id
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ String?
Youtube channel thumbnail
getter/setter pair
title ↔ String?
Youtube channel title
getter/setter pair
videoCount ↔ String?
Youtube channel number of videos
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited