PlayList class

Constructors

PlayList({String? playListId, List<Thumbnail>? thumbnails, String? title, String? channelName, String? videoCount})
PlayList.fromMap(Map<String, dynamic>? map)
factory

Properties

channelName ↔ String?
Youtube playlist channel name
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
playListId ↔ String?
Youtube playlist id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnails ↔ List<Thumbnail>?
Youtube playlist thumbnails
getter/setter pair
title ↔ String?
Youtube playlist title
getter/setter pair
videoCount ↔ String?
Youtube playlist number of videos
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited